#FlowIncomePredict

This is a package for predicting income or flow with history data. There are two method to calculate the data, correlation
and Fréchet distance. Fréchet distance is a better recommended method.

https://github.com/wufeipku/FlowIncomePredict.git